bayespy.nodes.SwitchingGaussianMarkovChain.initialize_from_value
================================================================

.. currentmodule:: bayespy.nodes

.. automethod:: SwitchingGaussianMarkovChain.initialize_from_value